@@ -384,7 +384,7 @@ private Q_SLOTS:
         Incidence::Ptr incidence = Incidence::Ptr(new Event());
         incidence->setUid(QStringLiteral("test123uid"));
         incidence->setSummary(QStringLiteral("summary"));
-        incidence->setOrganizer(Person::Ptr(new Person(QStringLiteral("orga"), QStringLiteral("orga@dev.nul"))));
+        incidence->setOrganizer(Person(QStringLiteral("orga"), QStringLiteral("orga@dev.nul")));
         incidence->setDirtyFields(QSet<IncidenceBase::Field>());
         item.setPayload<KCalCore::Incidence::Ptr>(incidence);
         ItemCreateJob *job = new ItemCreateJob(item, mCollection, this);
@@ -424,16 +424,16 @@ private Q_SLOTS:
         QTest::addColumn<Event::Ptr>("event");
         QTest::addColumn<bool>("expectReset");
 
-        const Attendee::Ptr us = Attendee::Ptr(new Attendee(QString(), s_ourEmail));
-        us->setStatus(Attendee::Accepted);
-        const Attendee::Ptr mia = Attendee::Ptr(new Attendee(QStringLiteral("Mia Wallace"), QStringLiteral("mia@dev.nul")));
-        mia->setStatus(Attendee::Declined);
-        mia->setRSVP(false);
-        const Attendee::Ptr vincent = Attendee::Ptr(new Attendee(QStringLiteral("Vincent"), QStringLiteral("vincent@dev.nul")));
-        vincent->setStatus(Attendee::Delegated);
-        const Attendee::Ptr jules = Attendee::Ptr(new Attendee(QStringLiteral("Jules"), QStringLiteral("jules@dev.nul")));
-        jules->setStatus(Attendee::Accepted);
-        jules->setRole(Attendee::NonParticipant);
+        Attendee us(QString(), s_ourEmail);
+        us.setStatus(Attendee::Accepted);
+        Attendee mia(QStringLiteral("Mia Wallace"), QStringLiteral("mia@dev.nul"));
+        mia.setStatus(Attendee::Declined);
+        mia.setRSVP(false);
+        Attendee vincent(QStringLiteral("Vincent"), QStringLiteral("vincent@dev.nul"));
+        vincent.setStatus(Attendee::Delegated);
+        Attendee jules(QStringLiteral("Jules"), QStringLiteral("jules@dev.nul"));
+        jules.setStatus(Attendee::Accepted);
+        jules.setRole(Attendee::NonParticipant);
 
         // we as organizator
         Item item;
@@ -444,7 +444,7 @@ private Q_SLOTS:
         incidence->setDtEnd(QDateTime(QDate(2006, 1, 8), QTime(14, 0, 0), Qt::UTC));
         incidence->setAllDay(false);
         incidence->setLocation(QStringLiteral("location"));
-        incidence->setOrganizer(Person::Ptr(new Person(QString(), s_ourEmail)));
+        incidence->setOrganizer(Person(QString(), s_ourEmail));
         incidence->addAttendee(us);
         incidence->addAttendee(mia);
         incidence->addAttendee(vincent);
@@ -496,7 +496,7 @@ private Q_SLOTS:
         incidence2->setDtEnd(QDateTime(QDate(2006, 1, 8), QTime(14, 0, 0), Qt::UTC));
         incidence2->setAllDay(false);
         incidence2->setLocation(QStringLiteral("location"));
-        incidence2->setOrganizer(Person::Ptr(new Person(QStringLiteral("External organizator"), QStringLiteral("exorga@dev.nul"))));
+        incidence2->setOrganizer(Person(QStringLiteral("External organizator"), QStringLiteral("exorga@dev.nul")));
         incidence2->addAttendee(us);
         incidence2->addAttendee(mia);
         incidence2->addAttendee(vincent);
@@ -569,22 +569,22 @@ private Q_SLOTS:
         QCOMPARE(incidence->revision(), revision + 1);
 
         if (expectReset) {
-            if (incidence->organizer()->email() == s_ourEmail) {
-                QCOMPARE(incidence->attendeeByMail(s_ourEmail)->status(), Attendee::Accepted);
+            if (incidence->organizer().email() == s_ourEmail) {
+                QCOMPARE(incidence->attendeeByMail(s_ourEmail).status(), Attendee::Accepted);
             } else {
-                QCOMPARE(incidence->attendeeByMail(s_ourEmail)->status(), Attendee::NeedsAction);
+                QCOMPARE(incidence->attendeeByMail(s_ourEmail).status(), Attendee::NeedsAction);
             }
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul"))->status(), Attendee::NeedsAction);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul"))->RSVP(), true);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul"))->status(), Attendee::Delegated);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul"))->RSVP(), false);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul"))->status(), Attendee::Accepted);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul"))->RSVP(), false);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul")).status(), Attendee::NeedsAction);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul")).RSVP(), true);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul")).status(), Attendee::Delegated);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul")).RSVP(), false);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul")).status(), Attendee::Accepted);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul")).RSVP(), false);
         } else {
-            QCOMPARE(incidence->attendeeByMail(s_ourEmail)->status(), Attendee::Accepted);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul"))->status(), Attendee::Declined);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul"))->status(), Attendee::Delegated);
-            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul"))->status(), Attendee::Accepted);
+            QCOMPARE(incidence->attendeeByMail(s_ourEmail).status(), Attendee::Accepted);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("mia@dev.nul")).status(), Attendee::Declined);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("vincent@dev.nul")).status(), Attendee::Delegated);
+            QCOMPARE(incidence->attendeeByMail(QLatin1String("jules@dev.nul")).status(), Attendee::Accepted);
         }
         delete fetchJob;
     }
