@@ -133,8 +133,7 @@ private Q_SLOTS:
         MailClient::Result expectedResult = MailClient::ResultNoAttendees;
         const int expectedTransportId = 69372773; // from tests/unittestenv/kdehome/share/config/mailtransports
         const QString expectedFrom = QStringLiteral("unittests@dev.nul");   // from tests/unittestenv/kdehome/share/config/emailidentities
-        KCalCore::Person::Ptr organizer(new KCalCore::Person(QStringLiteral("Organizer"),
-                                                             QStringLiteral("unittests@dev.nul")));
+        KCalCore::Person organizer(QStringLiteral("Organizer"), QStringLiteral("unittests@dev.nul"));
 
         QStringList toList;
         QStringList toCcList;
@@ -145,8 +144,7 @@ private Q_SLOTS:
                                       << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One attendee, but without e-mail
-        KCalCore::Attendee::Ptr attendee(new KCalCore::Attendee(QStringLiteral("name1"),
-                                                                QString()));
+        KCalCore::Attendee attendee(QStringLiteral("name1"), QString());
         incidence = KCalCore::Incidence::Ptr(new KCalCore::Event());
         incidence->addAttendee(attendee);
         expectedResult = MailClient::ResultReallyNoAttendees;
@@ -155,8 +153,7 @@ private Q_SLOTS:
                                                  << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One valid attendee
-        attendee = KCalCore::Attendee::Ptr(new KCalCore::Attendee(QStringLiteral("name1"),
-                                                                  QStringLiteral("test@foo.org")));
+        attendee = KCalCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
         incidence = KCalCore::Incidence::Ptr(new KCalCore::Event());
         incidence->addAttendee(attendee);
         incidence->setOrganizer(organizer);
@@ -167,8 +164,7 @@ private Q_SLOTS:
                                       << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One valid attendee
-        attendee = KCalCore::Attendee::Ptr(new KCalCore::Attendee(QStringLiteral("name1"),
-                                                                  QStringLiteral("test@foo.org")));
+        attendee = KCalCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
         incidence = KCalCore::Incidence::Ptr(new KCalCore::Event());
         incidence->setOrganizer(organizer);
         incidence->addAttendee(attendee);
@@ -181,8 +177,7 @@ private Q_SLOTS:
                                            << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // One valid attendee, and bcc me
-        attendee = KCalCore::Attendee::Ptr(new KCalCore::Attendee(QStringLiteral("name1"),
-                                                                  QStringLiteral("test@foo.org")));
+        attendee = KCalCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
         incidence = KCalCore::Incidence::Ptr(new KCalCore::Event());
         incidence->setOrganizer(organizer);
         incidence->addAttendee(attendee);
@@ -196,16 +191,11 @@ private Q_SLOTS:
                                   << toList << toCcList << toBccList;
         //----------------------------------------------------------------------------------------------
         // Test CC list
-        attendee = KCalCore::Attendee::Ptr(new KCalCore::Attendee(QStringLiteral("name1"),
-                                                                  QStringLiteral("test@foo.org")));
-        KCalCore::Attendee::Ptr optionalAttendee =
-            KCalCore::Attendee::Ptr(new KCalCore::Attendee(QStringLiteral("opt"),
-                                                           QStringLiteral("optional@foo.org")));
-        KCalCore::Attendee::Ptr nonParticipant =
-            KCalCore::Attendee::Ptr(new KCalCore::Attendee(QStringLiteral("non"),
-                                                           QStringLiteral("non@foo.org")));
-        optionalAttendee->setRole(KCalCore::Attendee::OptParticipant);
-        nonParticipant->setRole(KCalCore::Attendee::NonParticipant);
+        attendee = KCalCore::Attendee(QStringLiteral("name1"), QStringLiteral("test@foo.org"));
+        KCalCore::Attendee optionalAttendee(QStringLiteral("opt"), QStringLiteral("optional@foo.org"));
+        KCalCore::Attendee nonParticipant(QStringLiteral("non"), QStringLiteral("non@foo.org"));
+        optionalAttendee.setRole(KCalCore::Attendee::OptParticipant);
+        nonParticipant.setRole(KCalCore::Attendee::NonParticipant);
         incidence = KCalCore::Incidence::Ptr(new KCalCore::Event());
         incidence->setOrganizer(organizer);
         incidence->addAttendee(attendee);
@@ -296,8 +286,7 @@ private Q_SLOTS:
         MailClient::Result expectedResult = MailClient::ResultSuccess;
         const int expectedTransportId = 69372773; // from tests/unittestenv/kdehome/share/config/mailtransports
         QString expectedFrom = from; // from tests/unittestenv/kdehome/share/config/emailidentities
-        KCalCore::Person::Ptr organizer(new KCalCore::Person(QStringLiteral("Organizer"),
-                                                             QStringLiteral("unittests@dev.nul")));
+        KCalCore::Person organizer(QStringLiteral("Organizer"), QStringLiteral("unittests@dev.nul"));
         incidence->setOrganizer(organizer);
 
         QStringList toList;
@@ -376,8 +365,7 @@ private Q_SLOTS:
         MailClient::Result expectedResult = MailClient::ResultSuccess;
         const int expectedTransportId = 69372773; // from tests/unittestenv/kdehome/share/config/mailtransports
         QString expectedFrom = from; // from tests/unittestenv/kdehome/share/config/emailidentities
-        KCalCore::Person::Ptr organizer(new KCalCore::Person(QStringLiteral("Organizer"),
-                                                             QStringLiteral("unittests@dev.nul")));
+        KCalCore::Person organizer(QStringLiteral("Organizer"), QStringLiteral("unittests@dev.nul"));
         QStringList toList;
         toList << QLatin1String(s_ourEmail);
         QStringList toBccList;
