@@ -123,9 +123,11 @@ void UnitTestBase::compareCalendars(const KCalCore::Calendar::Ptr &expectedCalen
         incidence->setUid(incidence->schedulingID());
         qDebug() << "We have incidece with uid=" << incidence->uid()
                  << "; instanceidentifier=" << incidence->instanceIdentifier();
-        foreach(const KCalCore::Attendee::Ptr &attendee, incidence->attendees()) {
-            attendee->setUid(attendee->email());
+        auto attendees = incidence->attendees();
+        for (auto &attendee : attendees) {
+            attendee.setUid(attendee.email());
         }
+        incidence->setAttendees(attendees);
     }
 
     // ... so we can compare them
@@ -133,14 +135,16 @@ void UnitTestBase::compareCalendars(const KCalCore::Calendar::Ptr &expectedCalen
         incidence->setUid(incidence->schedulingID());
         qDebug() << "We expect incidece with uid=" << incidence->uid()
                  << "; instanceidentifier=" << incidence->instanceIdentifier();
-        foreach(const KCalCore::Attendee::Ptr &attendee, incidence->attendees()) {
-            attendee->setUid(attendee->email());
+        auto attendees = incidence->attendees();
+        for (auto &attendee : attendees) {
+            attendee.setUid(attendee.email());
         }
+        incidence->setAttendees(attendees);
     }
 
     QCOMPARE(incidences.count(), expectedIncidences.count());
 
-    foreach(const KCalCore::Incidence::Ptr &expectedIncidence, expectedIncidences) {
+    for (const KCalCore::Incidence::Ptr &expectedIncidence : expectedIncidences) {
         KCalCore::Incidence::Ptr incidence;
         for (int i=0; i<incidences.count(); i++) {
             if (incidences.at(i)->instanceIdentifier() == expectedIncidence->instanceIdentifier()) {
