@@ -132,9 +132,9 @@ static bool compareString(const QString &left, const QString &right)
     }
 }
 
-static QString toString(const Attendee::Ptr &attendee)
+static QString toString(const Attendee &attendee)
 {
-    return attendee->name() + QLatin1Char('<') + attendee->email() + QLatin1Char('>');
+    return attendee.name() + QLatin1Char('<') + attendee.email() + QLatin1Char('>');
 }
 
 static QString toString(const Alarm::Ptr &)
@@ -142,7 +142,7 @@ static QString toString(const Alarm::Ptr &)
     return QString();
 }
 
-static QString toString(const Attachment::Ptr &)
+static QString toString(const Attachment &)
 {
     return QString();
 }
@@ -191,9 +191,9 @@ static void compareIncidenceBase(AbstractDifferencesReporter *reporter, const In
 {
     compareList(reporter, i18n("Attendees"), left->attendees(), right->attendees());
 
-    if (!compareString(left->organizer()->fullName(), right->organizer()->fullName())) {
+    if (!compareString(left->organizer().fullName(), right->organizer().fullName())) {
         reporter->addProperty(AbstractDifferencesReporter::ConflictMode, i18n("Organizer"),
-                              left->organizer()->fullName(), right->organizer()->fullName());
+                              left->organizer().fullName(), right->organizer().fullName());
     }
 
     if (!compareString(left->uid(), right->uid())) {
