@@ -180,7 +180,8 @@ void CalendarBasePrivate::collectionFetchResult(KJob *job)
     }
 
     bool isReadOnly = !(collection.rights() & Akonadi::Collection::CanChangeItem);
-    foreach (const Akonadi::Item &item, mItemsByCollection.values(collection.id())) {
+    const auto lst = mItemsByCollection.values(collection.id());
+    for (const Akonadi::Item &item : lst) {
         KCalCore::Incidence::Ptr incidence = CalendarUtils::incidence(item);
         incidence->setReadOnly(isReadOnly);
     }
@@ -662,18 +663,6 @@ bool CalendarBase::modifyIncidence(const KCalCore::Incidence::Ptr &newIncidence)
     return -1 != d->mIncidenceChanger->modifyIncidence(item_);
 }
 
-void CalendarBase::setWeakPointer(const QWeakPointer<CalendarBase> &pointer)
-{
-    Q_D(CalendarBase);
-    d->mWeakPointer = pointer;
-}
-
-QWeakPointer<CalendarBase> CalendarBase::weakPointer() const
-{
-    Q_D(const CalendarBase);
-    return d->mWeakPointer;
-}
-
 IncidenceChanger *CalendarBase::incidenceChanger() const
 {
     Q_D(const CalendarBase);
