@@ -109,13 +109,14 @@ bool CalFilterPartStatusProxyModel::filterAcceptsRow(int source_row, const QMode
     }
 
     // always show if we are the organizer
-    if (CalendarUtils::thatIsMe(incidence->organizer()->email())) {
+    if (CalendarUtils::thatIsMe(incidence->organizer().email())) {
         return true;
     }
 
-    foreach (const KCalCore::Attendee::Ptr &attendee, incidence->attendees()) {
+    const auto attendees = incidence->attendees();
+    for (const KCalCore::Attendee &attendee : attendees) {
         if (CalendarUtils::thatIsMe(attendee)) {
-            return !d->mBlockedStatusList.contains(attendee->status());
+            return !d->mBlockedStatusList.contains(attendee.status());
         }
     }
 
