@@ -62,7 +62,7 @@ static ITIPHandlerDialogDelegate::Action actionFromStatus(ITIPHandlerHelper::Sen
 
 static bool weAreOrganizer(const Incidence::Ptr &incidence)
 {
-    const QString email = incidence->organizer()->email();
+    const QString email = incidence->organizer().email();
     return Akonadi::CalendarUtils::thatIsMe(email);
 }
 
@@ -353,7 +353,7 @@ void IncidenceChanger::Private::handleDeleteJobResult(KJob *job)
                                     errorString));
         }
 
-        foreach (const Item &item, items) {
+        for (const Item &item : items) {
             // Werent deleted due to error
             mDeletedItemIds.remove(mDeletedItemIds.indexOf(item.id()));
         }
@@ -506,7 +506,7 @@ void IncidenceChanger::Private::handleInvitationsBeforeChange(const Change::Ptr
             connect(handler, &ITIPHandlerHelper::finished,
                     change.data(), &Change::emitUserDialogClosedBeforeChange);
 
-            foreach (const Akonadi::Item &item, change->originalItems) {
+            for (const Akonadi::Item &item : qAsConst(change->originalItems)) {
                 Q_ASSERT(item.hasPayload<KCalCore::Incidence::Ptr>());
                 Incidence::Ptr incidence = CalendarUtils::incidence(item);
                 if (!incidence->supportsGroupwareCommunication()) {
@@ -514,7 +514,7 @@ void IncidenceChanger::Private::handleInvitationsBeforeChange(const Change::Ptr
                 }
                 // We only send CANCEL if we're the organizer.
                 // If we're not, then we send REPLY with PartStat=Declined in handleInvitationsAfterChange()
-                if (Akonadi::CalendarUtils::thatIsMe(incidence->organizer()->email())) {
+                if (Akonadi::CalendarUtils::thatIsMe(incidence->organizer().email())) {
                     //TODO: not to popup all delete message dialogs at once :(
                     sendOk = false;
                     handler->sendIncidenceDeletedMessage(KCalCore::iTIPCancel, incidence);
@@ -617,7 +617,7 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
             handler->deleteLater();
             handler = nullptr;
             Q_ASSERT(!change->originalItems.isEmpty());
-            foreach (const Akonadi::Item &item, change->originalItems) {
+            for (const Akonadi::Item &item : qAsConst(change->originalItems)) {
                 Q_ASSERT(item.hasPayload());
                 Incidence::Ptr incidence = CalendarUtils::incidence(item);
                 Q_ASSERT(incidence);
@@ -625,17 +625,17 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
                     continue;
                 }
 
-                if (!Akonadi::CalendarUtils::thatIsMe(incidence->organizer()->email())) {
+                if (!Akonadi::CalendarUtils::thatIsMe(incidence->organizer().email())) {
                     const QStringList myEmails = Akonadi::CalendarUtils::allEmails();
                     bool notifyOrganizer = false;
-                    KCalCore::Attendee::Ptr me(incidence->attendeeByMails(myEmails));
-                    if (me) {
-                        if (me->status() == KCalCore::Attendee::Accepted ||
-                                me->status() == KCalCore::Attendee::Delegated) {
+                    const KCalCore::Attendee me(incidence->attendeeByMails(myEmails));
+                    if (!me.isNull()) {
+                        if (me.status() == KCalCore::Attendee::Accepted ||
+                                me.status() == KCalCore::Attendee::Delegated) {
                             notifyOrganizer = true;
                         }
-                        KCalCore::Attendee::Ptr newMe(new KCalCore::Attendee(*me));
-                        newMe->setStatus(KCalCore::Attendee::Declined);
+                        KCalCore::Attendee newMe(me);
+                        newMe.setStatus(KCalCore::Attendee::Declined);
                         incidence->clearAttendees();
                         incidence->addAttendee(newMe);
                         //break;
@@ -659,7 +659,7 @@ void IncidenceChanger::Private::handleInvitationsAfterChange(const Change::Ptr &
             Incidence::Ptr newIncidence = CalendarUtils::incidence(change->newItem);
 
             if (!newIncidence->supportsGroupwareCommunication() ||
-                    !Akonadi::CalendarUtils::thatIsMe(newIncidence->organizer()->email())) {
+                    !Akonadi::CalendarUtils::thatIsMe(newIncidence->organizer().email())) {
                 // If we're not the organizer, the user already saw the "Do you really want to do this, incidence will become out of sync"
                 break;
             }
@@ -701,10 +701,10 @@ bool IncidenceChanger::Private::myAttendeeStatusChanged(const Incidence::Ptr &ne
 {
     Q_ASSERT(newInc);
     Q_ASSERT(oldInc);
-    const Attendee::Ptr oldMe = oldInc->attendeeByMails(myEmails);
-    const Attendee::Ptr newMe = newInc->attendeeByMails(myEmails);
+    const Attendee oldMe = oldInc->attendeeByMails(myEmails);
+    const Attendee newMe = newInc->attendeeByMails(myEmails);
 
-    return oldMe && newMe && oldMe->status() != newMe->status();
+    return !oldMe.isNull() && !newMe.isNull() && oldMe.status() != newMe.status();
 }
 
 IncidenceChanger::IncidenceChanger(QObject *parent)
@@ -816,7 +816,7 @@ int IncidenceChanger::deleteIncidences(const Item::List &items, QWidget *parent)
     }
 
     Item::List itemsToDelete;
-    foreach (const Item &item, items) {
+    for (const Item &item : items) {
         if (d->deleteAlreadyCalled(item.id())) {
             // IncidenceChanger::deleteIncidence() called twice, ignore this one.
             qCDebug(AKONADICALENDAR_LOG) << "Item " << item.id() << " already deleted or being deleted, skipping";
@@ -876,7 +876,7 @@ void IncidenceChanger::Private::deleteIncidences2(int changeId, ITIPHandlerHelpe
     }
 
     mDeletedItemIds.reserve(mDeletedItemIds.count() + change->originalItems.count());
-    foreach (const Item &item, change->originalItems) {
+    for (const Item &item : qAsConst(change->originalItems)) {
         mDeletedItemIds << item.id();
     }
 
@@ -1034,13 +1034,15 @@ void IncidenceChanger::Private::performModification2(int changeId, ITIPHandlerHe
                         << IncidenceBase::FieldDuration
                         << IncidenceBase::FieldRecurrence;
         if (!(incidence->dirtyFields() & resetPartStatus).isEmpty() && weAreOrganizer(incidence)) {
-            foreach (const Attendee::Ptr &attendee, incidence->attendees()) {
-                if (attendee->role() != Attendee::NonParticipant &&
-                        attendee->status() != Attendee::Delegated && !Akonadi::CalendarUtils::thatIsMe(attendee)) {
-                    attendee->setStatus(Attendee::NeedsAction);
-                    attendee->setRSVP(true);
+            auto attendees = incidence->attendees();
+            for (auto &attendee : attendees) {
+                if (attendee.role() != Attendee::NonParticipant &&
+                        attendee.status() != Attendee::Delegated && !Akonadi::CalendarUtils::thatIsMe(attendee)) {
+                    attendee.setStatus(Attendee::NeedsAction);
+                    attendee.setRSVP(true);
                 }
             }
+            incidence->setAttendees(attendees);
         }
     }
 
@@ -1325,7 +1327,7 @@ bool IncidenceChanger::Private::allowAtomicOperation(int atomicOperationId,
             allow = !operation->m_itemIdsInOperation.contains(change->newItem.id());
         } else if (change->type == ChangeTypeDelete) {
             DeletionChange::Ptr deletion = change.staticCast<DeletionChange>();
-            foreach (Akonadi::Item::Id id, deletion->mItemIds) {
+            for (Akonadi::Item::Id id : qAsConst(deletion->mItemIds)) {
                 if (operation->m_itemIdsInOperation.contains(id)) {
                     allow = false;
                     break;
