@@ -170,22 +170,24 @@ void ITIPHandler::processiTIPMessage(const QString &receiver,
             action.startsWith(QLatin1String("counter"))) {
         // Find myself and set my status. This can't be done in the scheduler,
         // since this does not know the choice I made in the KMail bpf
-        const KCalCore::Attendee::List attendees = d->m_incidence->attendees();
-        for (const KCalCore::Attendee::Ptr &attendee : attendees) {
-            if (attendee->email() == receiver) {
+        KCalCore::Attendee::List attendees = d->m_incidence->attendees();
+        for (auto &attendee : attendees) {
+            if (attendee.email() == receiver) {
                 if (action.startsWith(QLatin1String("accepted"))) {
-                    attendee->setStatus(KCalCore::Attendee::Accepted);
+                    attendee.setStatus(KCalCore::Attendee::Accepted);
                 } else if (action.startsWith(QLatin1String("tentative"))) {
-                    attendee->setStatus(KCalCore::Attendee::Tentative);
+                    attendee.setStatus(KCalCore::Attendee::Tentative);
                 } else if (CalendarSettings::self()->outlookCompatCounterProposals() &&
                            action.startsWith(QLatin1String("counter"))) {
-                    attendee->setStatus(KCalCore::Attendee::Tentative);
+                    attendee.setStatus(KCalCore::Attendee::Tentative);
                 } else if (action.startsWith(QLatin1String("delegated"))) {
-                    attendee->setStatus(KCalCore::Attendee::Delegated);
+                    attendee.setStatus(KCalCore::Attendee::Delegated);
                 }
                 break;
             }
         }
+        d->m_incidence->setAttendees(attendees);
+
         if (CalendarSettings::self()->outlookCompatCounterProposals() ||
                 !action.startsWith(QLatin1String("counter"))) {
             d->m_scheduler->acceptTransaction(d->m_incidence, d->calendar(), d->m_method, status, receiver);
@@ -370,10 +372,8 @@ void ITIPHandler::sendAsICalendar(const KCalCore::Incidence::Ptr &originalIncide
     QPointer<Akonadi::PublishDialog> publishdlg = new Akonadi::PublishDialog;
     if (publishdlg->exec() == QDialog::Accepted && publishdlg) {
         const QString recipients = publishdlg->addresses();
-        if (incidence->organizer()->isEmpty()) {
-            incidence->setOrganizer(KCalCore::Person::Ptr(
-                                        new KCalCore::Person(Akonadi::CalendarUtils::fullName(),
-                                                Akonadi::CalendarUtils::email())));
+        if (incidence->organizer().isEmpty()) {
+            incidence->setOrganizer(KCalCore::Person(Akonadi::CalendarUtils::fullName(), Akonadi::CalendarUtils::email()));
         }        
 
         if (incidence->hasRecurrenceId()) {
