@@ -66,16 +66,16 @@ void MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence,
         return;
     }
 
-    const QString from = incidence->organizer()->fullName();
-    const QString organizerEmail = incidence->organizer()->email();
+    const QString from = incidence->organizer().fullName();
+    const QString organizerEmail = incidence->organizer().email();
 
     QStringList toList;
     QStringList ccList;
     const int numberOfAttendees = attendees.count();
     for (int i = 0; i < numberOfAttendees; ++i) {
-        KCalCore::Attendee::Ptr a = attendees.at(i);
+        const KCalCore::Attendee a = attendees.at(i);
 
-        const QString email = a->email();
+        const QString email = a.email();
         if (email.isEmpty()) {
             continue;
         }
@@ -88,11 +88,11 @@ void MailClient::mailAttendees(const KCalCore::IncidenceBase::Ptr &incidence,
         }
 
         // Optional Participants and Non-Participants are copied on the email
-        if (a->role() == KCalCore::Attendee::OptParticipant ||
-                a->role() == KCalCore::Attendee::NonParticipant) {
-            ccList << a->email();
+        if (a.role() == KCalCore::Attendee::OptParticipant ||
+                a.role() == KCalCore::Attendee::NonParticipant) {
+            ccList << a.email();
         } else {
-            toList << a->email();
+            toList << a.email();
         }
     }
     if (toList.isEmpty() && ccList.isEmpty()) {
@@ -129,7 +129,7 @@ void MailClient::mailOrganizer(const KCalCore::IncidenceBase::Ptr &incidence,
                                const QString &attachment,
                                const QString &sub, const QString &mailTransport)
 {
-    const QString to = incidence->organizer()->fullName();
+    const QString to = incidence->organizer().fullName();
     QString subject = sub;
 
     if (incidence->type() != KCalCore::Incidence::TypeFreeBusy) {
