@@ -28,7 +28,6 @@
 #include <kcalcore/icalformat.h>
 #include <kcalcore/incidence.h>
 #include <kcalcore/schedulemessage.h>
-#include <kcalutils/scheduler.h>
 #include <identitymanager.h>
 #include <identity.h>
 
@@ -65,7 +64,7 @@ MailScheduler::~MailScheduler()
 KIdentityManagement::Identity MailScheduler::Private::identityForIncidence(const KCalCore::IncidenceBase::Ptr &incidence) const
 {
     const auto organizer = incidence->organizer();
-    const QString organizerEmail = organizer ? organizer->email() : CalendarUtils::email();
+    const QString organizerEmail = !organizer.isEmpty() ? organizer.email() : CalendarUtils::email();
     return m_identityManager->identityForAddress(organizerEmail);
 }
 
