@@ -225,7 +225,7 @@ void Scheduler::acceptRequest(const IncidenceBase::Ptr &incidenceBase,
             const Attendee::List attendees = existingIncidence->attendees();
             Attendee::List::ConstIterator ait;
             for (ait = attendees.begin(); ait != attendees.end(); ++ait) {
-                if ((*ait)->email() == email && (*ait)->status() == Attendee::NeedsAction) {
+                if ((*ait).email() == email && (*ait).status() == Attendee::NeedsAction) {
                     // This incidence wasn't created by me - it's probably in a shared folder
                     // and meant for someone else, ignore it.
                     qCDebug(AKONADICALENDAR_LOG) << "ignoring " << existingUid << " since I'm still NeedsAction there";
@@ -354,7 +354,7 @@ void Scheduler::acceptCancel(const IncidenceBase::Ptr &incidenceBase,
 
     Result result = ResultIncidenceToDeleteNotFound;
     QString errorString = i18n("Could not find incidence to delete.");
-    foreach (const KCalCore::Incidence::Ptr &existingIncidence, existingIncidences) {
+    for (const KCalCore::Incidence::Ptr &existingIncidence : existingIncidences) {
         qCDebug(AKONADICALENDAR_LOG) << "Considering this found event ("
                                      << (existingIncidence->isReadOnly() ? "readonly" : "readwrite")
                                      << ") :" << mFormat->toString(existingIncidence);
@@ -379,9 +379,9 @@ void Scheduler::acceptCancel(const IncidenceBase::Ptr &incidenceBase,
         // on the invitation" case. So check the attendee status of the attendee.
         bool isMine = true;
         const Attendee::List attendees = existingIncidence->attendees();
-        for (const KCalCore::Attendee::Ptr &attendee : attendees) {
-            if (attendee->email() == attendeeEmail &&
-                    attendee->status() == Attendee::NeedsAction) {
+        for (const KCalCore::Attendee &attendee : attendees) {
+            if (attendee.email() == attendeeEmail &&
+                    attendee.status() == Attendee::NeedsAction) {
                 // This incidence wasn't created by me - it's probably in a shared
                 // folder and meant for someone else, ignore it.
                 qCDebug(AKONADICALENDAR_LOG) << "ignoring " << existingUid << " since I'm still NeedsAction there";
@@ -471,42 +471,37 @@ void Scheduler::acceptReply(const IncidenceBase::Ptr &incidenceBase,
     if (incidence) {
         //get matching attendee in calendar
         qCDebug(AKONADICALENDAR_LOG) << "match found!";
-        Attendee::List attendeesIn = incidenceBase->attendees();
+        const Attendee::List attendeesIn = incidenceBase->attendees();
         Attendee::List attendeesNew;
         Attendee::List attendeesEv = incidence->attendees();
-        Attendee::List::ConstIterator inIt;
-        Attendee::List::ConstIterator evIt;
-        for (inIt = attendeesIn.constBegin(); inIt != attendeesIn.constEnd(); ++inIt) {
-            Attendee::Ptr attIn = *inIt;
+        for (const auto &attIn : attendeesIn) {
             bool found = false;
-            for (evIt = attendeesEv.constBegin(); evIt != attendeesEv.constEnd(); ++evIt) {
-                Attendee::Ptr attEv = *evIt;
-                if (attIn->email().toLower() == attEv->email().toLower()) {
+            for (auto &attEv : attendeesEv) {
+                if (attIn.email().toLower() == attEv.email().toLower()) {
                     //update attendee-info
                     qCDebug(AKONADICALENDAR_LOG) << "update attendee";
-                    attEv->setStatus(attIn->status());
-                    attEv->setDelegate(attIn->delegate());
-                    attEv->setDelegator(attIn->delegator());
+                    attEv.setStatus(attIn.status());
+                    attEv.setDelegate(attIn.delegate());
+                    attEv.setDelegator(attIn.delegator());
                     result = ResultSuccess;
                     errorString.clear();
                     found = true;
                 }
             }
-            if (!found && attIn->status() != Attendee::Declined) {
+            if (!found && attIn.status() != Attendee::Declined) {
                 attendeesNew.append(attIn);
             }
         }
+        incidence->setAttendees(attendeesEv);
 
         bool attendeeAdded = false;
-        for (Attendee::List::ConstIterator it = attendeesNew.constBegin(), end = attendeesNew.constEnd();
-                it != end; ++it) {
-            Attendee::Ptr attNew = *it;
+        for (const auto &attNew : qAsConst(attendeesNew)) {
             QString msg =
                 i18nc("@info", "%1 wants to attend %2 but was not invited.",
-                      attNew->fullName(), incidence->summary());
-            if (!attNew->delegator().isEmpty()) {
+                      attNew.fullName(), incidence->summary());
+            if (!attNew.delegator().isEmpty()) {
                 msg = i18nc("@info", "%1 wants to attend %2 on behalf of %3.",
-                            attNew->fullName(), incidence->summary(), attNew->delegator());
+                            attNew.fullName(), incidence->summary(), attNew.delegator());
             }
             if (KMessageBox::questionYesNo(
                         nullptr, msg, i18nc("@title", "Uninvited attendee"),
@@ -515,15 +510,15 @@ void Scheduler::acceptReply(const IncidenceBase::Ptr &incidenceBase,
                 Incidence::Ptr cancel = incidence;
                 cancel->addComment(i18nc("@info",
                                          "The organizer rejected your attendance at this meeting."));
-                performTransaction(incidenceBase, iTIPCancel, attNew->fullName());
+                performTransaction(incidenceBase, iTIPCancel, attNew.fullName());
                 continue;
             }
 
-            Attendee::Ptr a(new Attendee(attNew->name(), attNew->email(), attNew->RSVP(),
-                                         attNew->status(), attNew->role(), attNew->uid()));
+            Attendee a(attNew.name(), attNew.email(), attNew.RSVP(),
+                                         attNew.status(), attNew.role(), attNew.uid());
 
-            a->setDelegate(attNew->delegate());
-            a->setDelegator(attNew->delegator());
+            a.setDelegate(attNew.delegate());
+            a.setDelegator(attNew.delegator());
             incidence->addAttendee(a);
 
             result = ResultSuccess;
@@ -617,14 +612,14 @@ void Scheduler::acceptFreeBusy(const IncidenceBase::Ptr &incidence, iTIPMethod m
 
     qCDebug(AKONADICALENDAR_LOG) << "freeBusyDirName:" << freeBusyDir();
 
-    Person::Ptr from;
+    Person from;
     if (method == iTIPPublish) {
         from = freebusy->organizer();
     }
     if ((method == iTIPReply) && (freebusy->attendeeCount() == 1)) {
-        Attendee::Ptr attendee = freebusy->attendees().at(0);
-        from->setName(attendee->name());
-        from->setEmail(attendee->email());
+        Attendee attendee = freebusy->attendees().at(0);
+        from.setName(attendee.name());
+        from.setEmail(attendee.email());
     }
 
     if (!d->mFreeBusyCache->saveFreeBusy(freebusy, from)) {
